package com.ynet.life.base.logon;

import com.ynet.gene.core.Context;
import com.ynet.life.base.LifeDBAccess;
import com.ynet.life.base.LifeStandard;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import java.sql.Connection;
import java.sql.SQLException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.GregorianCalendar;
import java.util.List;

/* loaded from: com_ynet_life_base_logon.jar:com/ynet/life/base/logon/LifeLogonEntry.class */
public class LifeLogonEntry {
    private String userId;
    private String sessionId;
    private String serverAddress;
    private static LifeLogonEntryConfig CONFIG;

    public LifeLogonEntry(String userId, String sessionId, String serverAddress) {
        this.userId = userId;
        this.sessionId = sessionId;
        this.serverAddress = serverAddress;
    }

    public static void initialize(LifeLogonEntryConfig config) {
        CONFIG = config;
    }

    public static LifeLogonEntry getCurrentUserLogonEntry(Context context) throws TranFailException {
        return getUserLogonEntry(CONFIG.getUserId(context));
    }

    public static LifeLogonEntry getUserLogonEntry(String userId) throws TranFailException {
        Connection connection = null;
        String lastSessionID = null;
        String lastLogonServer = null;
        try {
            try {
                connection = LifeDBAccess.getConnection();
                List inParam = new ArrayList();
                inParam.add(userId);
                List result = LifeDBAccess.querySingleResult(connection, CONFIG.getSelectSQL(), inParam, 2);
                if (2 == result.size()) {
                    lastSessionID = (String) result.get(0);
                    lastLogonServer = (String) result.get(1);
                }
                if (connection != null) {
                    LifeDBAccess.releaseConnection(connection);
                }
                return new LifeLogonEntry(userId, lastSessionID, lastLogonServer);
            } catch (TranFailException ex) {
                Trace.logError("LifeSession", ex.getShowMessage(), ex);
                throw ex;
            }
        } catch (Throwable th) {
            if (connection != null) {
                LifeDBAccess.releaseConnection(connection);
            }
            throw th;
        }
    }

    public void addToDB() throws TranFailException {
        Connection connection = null;
        try {
            try {
                try {
                    connection = LifeDBAccess.getConnection();
                    List inParam = new ArrayList();
                    inParam.add(this.userId);
                    inParam.add(this.sessionId);
                    inParam.add(LifeStandard.getServerTime("yyyyMMddHHmmss"));
                    inParam.add(this.serverAddress);
                    LifeDBAccess.executeSQLUpdate(connection, CONFIG.getInsertSQL(), inParam);
                    connection.commit();
                    LifeDBAccess.releaseConnection(connection);
                } catch (SQLException se) {
                    Trace.logError("LifeJDBC", se.getMessage(), se);
                    throw new TranFailException(se);
                }
            } catch (TranFailException ex) {
                Trace.logError("LifeSession", ex.getShowMessage(), ex);
                throw ex;
            }
        } catch (Throwable th) {
            LifeDBAccess.releaseConnection(connection);
            throw th;
        }
    }

    public void update() throws TranFailException {
        Connection connection = null;
        try {
            try {
                try {
                    connection = LifeDBAccess.getConnection();
                    List inParam = new ArrayList();
                    inParam.add(this.sessionId);
                    inParam.add(this.serverAddress);
                    inParam.add(LifeStandard.getServerTime("yyyyMMddHHmmss"));
                    inParam.add(this.userId);
                    LifeDBAccess.executeSQLUpdate(connection, CONFIG.getUpdateSQL(), inParam);
                    connection.commit();
                    LifeDBAccess.releaseConnection(connection);
                } catch (SQLException se) {
                    Trace.logError("LifeJDBC", se.getMessage(), se);
                    throw new TranFailException(se);
                }
            } catch (TranFailException ex) {
                Trace.logError("LifeSession", ex.getShowMessage(), ex);
                throw ex;
            }
        } catch (Throwable th) {
            LifeDBAccess.releaseConnection(connection);
            throw th;
        }
    }

    public static void cleanTable() throws TranFailException {
        Connection connection = null;
        try {
            try {
                try {
                    connection = LifeDBAccess.getConnection();
                    List inParam = new ArrayList();
                    inParam.add(getDifferentTime(-24));
                    LifeDBAccess.executeSQLUpdate(connection, CONFIG.getCleanSQL(), inParam);
                    connection.commit();
                    LifeDBAccess.releaseConnection(connection);
                } catch (SQLException se) {
                    Trace.logError("LifeJDBC", se.getMessage(), se);
                    throw new TranFailException(se);
                }
            } catch (TranFailException ex) {
                Trace.logError("LifeSession", ex.getShowMessage(), ex);
                throw ex;
            }
        } catch (Throwable th) {
            LifeDBAccess.releaseConnection(connection);
            throw th;
        }
    }

    private static String getDifferentTime(int hour) {
        GregorianCalendar calendar = (GregorianCalendar) Calendar.getInstance();
        calendar.add(10, hour);
        return new SimpleDateFormat("yyyyMMddHHmmss").format(calendar.getTime());
    }

    public String getUserId() {
        return this.userId;
    }

    public String getServerAddress() {
        return this.serverAddress;
    }

    public String getSessionId() {
        return this.sessionId;
    }

    public String toString() {
        StringBuffer retValue = new StringBuffer();
        retValue.append("LifeLogonEntry ( ").append(super.toString()).append("    userId = ").append(this.userId).append("    sessionId = ").append(this.sessionId).append("    serverAddress = ").append(this.serverAddress).append("     )");
        return retValue.toString();
    }
}
